[dna-commits] DNA SVN: r1372 - in trunk/dna-graph/src/main/java/org/jboss/dna/graph: request and 1 other directories.

dna-commits at lists.jboss.org dna-commits at lists.jboss.org
Mon Nov 30 16:53:48 EST 2009


Author: rhauch
Date: 2009-11-30 16:53:47 -0500 (Mon, 30 Nov 2009)
New Revision: 1372

Modified:
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/query/optimize/RewriteAsRangeCriteria.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/CloneBranchRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/CopyBranchRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/CreateNodeRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/DeleteBranchRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/DeleteChildrenRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/LockBranchRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/MoveBranchRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadAllChildrenRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadAllPropertiesRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadBlockOfChildrenRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadBranchRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadNextBlockOfChildrenRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadNodeRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadPropertyRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/RemovePropertyRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/RenameNodeRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/SetPropertyRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/UnlockBranchRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/UpdatePropertiesRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/VerifyNodeExistsRequest.java
   trunk/dna-graph/src/main/java/org/jboss/dna/graph/session/GraphSession.java
Log:
DNA-551 Fixed a couple of calls to 'Location.isSame()' that should have been fixed earlier.

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/query/optimize/RewriteAsRangeCriteria.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/query/optimize/RewriteAsRangeCriteria.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/query/optimize/RewriteAsRangeCriteria.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -48,7 +48,6 @@
 import org.jboss.dna.graph.query.plan.PlanNode.Type;
 import com.google.common.collect.ArrayListMultimap;
 import com.google.common.collect.Multimap;
-import com.google.common.collect.Multimaps;
 
 /**
  * An {@link OptimizerRule optimizer rule} that rewrites two {@link And AND-ed} {@link Constraint}s that constraint a dynamic

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/CloneBranchRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/CloneBranchRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/CloneBranchRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -167,10 +167,9 @@
      * 
      * @param fromLocation the actual location of the node being cloned
      * @param intoLocation the actual location of the new clone of the node
-     * @throws IllegalArgumentException if the either location is null; if the old location does not represent the
-     *         {@link Location#isSame(Location) same location} as the {@link #from() from location}; if the new location does not
-     *         represent the {@link Location#isSame(Location) same location} as the {@link #into() into location}; if the either
-     *         location does not have a path
+     * @throws IllegalArgumentException if the either location is null; if the old location is not {@link Location#equals(Object)
+     *         equal to} the {@link #from() from location}; if the new location is not {@link Location#equals(Object) equal to}
+     *         the {@link #into() into location}; if the either location does not have a path
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocations( Location fromLocation,

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/CopyBranchRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/CopyBranchRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/CopyBranchRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -203,10 +203,9 @@
      * 
      * @param fromLocation the actual location of the node being copied
      * @param intoLocation the actual location of the new copy of the node
-     * @throws IllegalArgumentException if the either location is null; if the old location does not represent the
-     *         {@link Location#isSame(Location) same location} as the {@link #from() from location}; if the new location does not
-     *         represent the {@link Location#isSame(Location) same location} as the {@link #into() into location}; if the either
-     *         location does not have a path
+     * @throws IllegalArgumentException if the either location is null; if the old location is not {@link Location#equals(Object)
+     *         equal to} the {@link #from() from location}; if the new location is not {@link Location#equals(Object) equal to}
+     *         the {@link #into() into location}; if the either location does not have a path
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocations( Location fromLocation,

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/CreateNodeRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/CreateNodeRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/CreateNodeRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -275,8 +275,8 @@
      * 
      * @param actual the actual location of the node being created, or null if the {@link #under() current location} should be
      *        used
-     * @throws IllegalArgumentException if the actual location does not represent the {@link Location#isSame(Location) same
-     *         location} as the {@link #under() current location}, or if the actual location does not have a path.
+     * @throws IllegalArgumentException if the actual location is not {@link Location#equals(Object) equal to} the
+     *         {@link #under() current location}, or if the actual location does not have a path.
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocationOfNode( Location actual ) {

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/DeleteBranchRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/DeleteBranchRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/DeleteBranchRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -88,8 +88,8 @@
      * and the actual location must have a {@link Location#getPath() path}.
      * 
      * @param actual the actual location of the node being deleted, or null if the {@link #at() current location} should be used
-     * @throws IllegalArgumentException if the actual location does not represent the {@link Location#isSame(Location) same
-     *         location} as the {@link #at() current location}, or if the actual location does not have a path.
+     * @throws IllegalArgumentException if the actual location is not {@link Location#equals(Object) equal to} the {@link #at()
+     *         current location}, or if the actual location does not have a path.
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocationOfNode( Location actual ) {

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/DeleteChildrenRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/DeleteChildrenRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/DeleteChildrenRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -92,8 +92,8 @@
      * and the actual location must have a {@link Location#getPath() path}.
      * 
      * @param actual the actual location of the node being deleted, or null if the {@link #at() current location} should be used
-     * @throws IllegalArgumentException if the actual location does not represent the {@link Location#isSame(Location) same
-     *         location} as the {@link #at() current location}, or if the actual location does not have a path.
+     * @throws IllegalArgumentException if the actual location is not {@link Location#equals(Object) equal to} the {@link #at()
+     *         current location}, or if the actual location does not have a path.
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocationOfNode( Location actual ) {

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/LockBranchRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/LockBranchRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/LockBranchRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -122,8 +122,8 @@
      * the actual location must have a {@link Location#getPath() path}.
      * 
      * @param actualLocation the actual location of the node before being locked
-     * @throws IllegalArgumentException if the either location is null or is missing its path, if the old location does not
-     *         represent the {@link Location#isSame(Location) same location} as the {@link #at() current location}
+     * @throws IllegalArgumentException if the either location is null or is missing its path, if the old location is not
+     *         {@link Location#equals(Object) equal to} the {@link #at() current location}
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocation( Location actualLocation ) {

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/MoveBranchRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/MoveBranchRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/MoveBranchRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -225,10 +225,9 @@
      * 
      * @param oldLocation the actual location of the node before being moved
      * @param newLocation the actual new location of the node
-     * @throws IllegalArgumentException if the either location is null, if the old location does not represent the
-     *         {@link Location#isSame(Location) same location} as the {@link #from() from location}, if the new location does not
-     *         represent the {@link Location#isSame(Location) same location} as the {@link #into() into location}, or if the
-     *         either location does not have a path
+     * @throws IllegalArgumentException if the either location is null, if the old location is not {@link Location#equals(Object)
+     *         equal to} the {@link #from() from location}, if the new location is not {@link Location#equals(Object) equal to}
+     *         the {@link #into() into location}, or if the either location does not have a path
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocations( Location oldLocation,

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadAllChildrenRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadAllChildrenRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadAllChildrenRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -187,9 +187,8 @@
      * 
      * @param actualLocation the actual location of the node being read, or null if the {@link #of() current location} should be
      *        used
-     * @throws IllegalArgumentException if the actual location does not represent the {@link Location#isSame(Location) same
-     *         location} as the {@link #of() current location}; if the actual location does not have a path; or if the actual
-     *         workspace name is null
+     * @throws IllegalArgumentException if the actual location is not {@link Location#equals(Object) equal to} the {@link #of()
+     *         current location}; if the actual location does not have a path; or if the actual workspace name is null
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocationOfNode( Location actualLocation ) {

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadAllPropertiesRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadAllPropertiesRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadAllPropertiesRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -189,8 +189,8 @@
      * processing the request, and the actual location must have a {@link Location#getPath() path}.
      * 
      * @param actual the actual location of the node being read, or null if the {@link #at() current location} should be used
-     * @throws IllegalArgumentException if the actual location does not represent the {@link Location#isSame(Location) same
-     *         location} as the {@link #at() current location}, or if the actual location does not have a path.
+     * @throws IllegalArgumentException if the actual location is not {@link Location#equals(Object) equal to} the {@link #at()
+     *         current location}, or if the actual location does not have a path.
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocationOfNode( Location actual ) {

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadBlockOfChildrenRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadBlockOfChildrenRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadBlockOfChildrenRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -234,8 +234,8 @@
      * the request, and the actual location must have a {@link Location#getPath() path}.
      * 
      * @param actual the actual location of the node being read, or null if the {@link #of() current location} should be used
-     * @throws IllegalArgumentException if the actual location does not represent the {@link Location#isSame(Location) same
-     *         location} as the {@link #of() current location}, or if the actual location does not have a path.
+     * @throws IllegalArgumentException if the actual location is not {@link Location#equals(Object) equal to} the {@link #of()
+     *         current location}, or if the actual location does not have a path.
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocationOfNode( Location actual ) {

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadBranchRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadBranchRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadBranchRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -363,8 +363,8 @@
      * the actual location must have a {@link Location#getPath() path}.
      * 
      * @param actual the actual location of the node being read, or null if the {@link #at() current location} should be used
-     * @throws IllegalArgumentException if the actual location does not represent the {@link Location#isSame(Location) same
-     *         location} as the {@link #at() current location}, or if the actual location does not have a path.
+     * @throws IllegalArgumentException if the actual location is not {@link Location#equals(Object) equal to} the {@link #at()
+     *         current location}, or if the actual location does not have a path.
      */
     public void setActualLocationOfNode( Location actual ) {
         if (!at.equals(actual)) { // not same if actual is null

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadNextBlockOfChildrenRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadNodeRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadNodeRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -253,8 +253,8 @@
      * when processing the request, and the actual location must have a {@link Location#getPath() path}.
      * 
      * @param actual the actual location of the node being read, or null if the {@link #at() current location} should be used
-     * @throws IllegalArgumentException if the actual location does not represent the {@link Location#isSame(Location) same
-     *         location} as the {@link #at() current location}, or if the actual location does not have a path.
+     * @throws IllegalArgumentException if the actual location is not {@link Location#equals(Object) equal to} the {@link #at()
+     *         current location}, or if the actual location does not have a path.
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocationOfNode( Location actual ) {

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadPropertyRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadPropertyRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadPropertyRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -128,8 +128,8 @@
      * the request, and the actual location must have a {@link Location#getPath() path}.
      * 
      * @param actual the actual location of the node being read, or null if the {@link #on() current location} should be used
-     * @throws IllegalArgumentException if the actual location does not represent the {@link Location#isSame(Location) same
-     *         location} as the {@link #on() current location}, or if the actual location does not have a path.
+     * @throws IllegalArgumentException if the actual location is not {@link Location#equals(Object) equal to} the {@link #on()
+     *         current location}, or if the actual location does not have a path.
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocationOfNode( Location actual ) {

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/RemovePropertyRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/RemovePropertyRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/RemovePropertyRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -104,13 +104,13 @@
      * and the actual location must have a {@link Location#getPath() path}.
      * 
      * @param actual the actual location of the node being updated, or null if the {@link #from() current location} should be used
-     * @throws IllegalArgumentException if the actual location does represent the {@link Location#isSame(Location) same location}
-     *         as the {@link #from() current location}, or if the actual location does not have a path.
+     * @throws IllegalArgumentException if the actual location is not {@link Location#equals(Object) equal to} the {@link #from()
+     *         current location}, or if the actual location does not have a path.
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocationOfNode( Location actual ) {
         checkNotFrozen();
-        if (!from.isSame(actual)) { // not same if actual is null
+        if (!from.equals(actual)) { // not same if actual is null
             throw new IllegalArgumentException(GraphI18n.actualLocationNotEqualToInputLocation.text(actual, from));
         }
         assert actual != null;

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/RenameNodeRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/SetPropertyRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/SetPropertyRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -106,8 +106,8 @@
      * and the actual location must have a {@link Location#getPath() path}.
      * 
      * @param actual the actual location of the node being updated, or null if the {@link #on() current location} should be used
-     * @throws IllegalArgumentException if the actual location does represent the {@link Location#isSame(Location) same location}
-     *         as the {@link #on() current location}, or if the actual location does not have a path.
+     * @throws IllegalArgumentException if the actual location is not {@link Location#equals(Object) equal to} the {@link #on()
+     *         current location}, or if the actual location does not have a path.
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocationOfNode( Location actual ) {

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/UnlockBranchRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/UnlockBranchRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/UnlockBranchRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -88,13 +88,13 @@
      * and the actual location must have a {@link Location#getPath() path}.
      * 
      * @param actualLocation the actual location of the node before being unlocked
-     * @throws IllegalArgumentException if the either location is null or is missing its path, if the old location does not
-     *         represent the {@link Location#isSame(Location) same location} as the {@link #at() current location}
+     * @throws IllegalArgumentException if the either location is null or is missing its path, if the old location is not
+     *         {@link Location#equals(Object) equal to} the {@link #at() current location}
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocation( Location actualLocation ) {
         checkNotFrozen();
-        if (!at.isSame(actualLocation)) { // not same if actual is null
+        if (!at.equals(actualLocation)) { // not same if actual is null
             throw new IllegalArgumentException(GraphI18n.actualLocationNotEqualToInputLocation.text(actualLocation, at));
         }
         assert actualLocation != null;

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/UpdatePropertiesRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/UpdatePropertiesRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/UpdatePropertiesRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -125,8 +125,8 @@
      * and the actual location must have a {@link Location#getPath() path}.
      * 
      * @param actual the actual location of the node being updated, or null if the {@link #on() current location} should be used
-     * @throws IllegalArgumentException if the actual location does represent the {@link Location#isSame(Location) same location}
-     *         as the {@link #on() current location}, or if the actual location does not have a path.
+     * @throws IllegalArgumentException if the actual location is not {@link Location#equals(Object) equal to} the {@link #on()
+     *         current location}, or if the actual location does not have a path.
      * @throws IllegalStateException if the request is frozen
      * @see #setNewProperties(Iterable)
      * @see #setNewProperties(Name...)

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/VerifyNodeExistsRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/VerifyNodeExistsRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/VerifyNodeExistsRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -87,8 +87,8 @@
      * processing the request, and the actual location must have a {@link Location#getPath() path}.
      * 
      * @param actual the actual location of the node being read, or null if the {@link #at() current location} should be used
-     * @throws IllegalArgumentException if the actual location does not represent the {@link Location#isSame(Location) same
-     *         location} as the {@link #at() current location}, or if the actual location does not have a path.
+     * @throws IllegalArgumentException if the actual location is not {@link Location#equals(Object) equal to} the {@link #at()
+     *         current location}, or if the actual location does not have a path.
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocationOfNode( Location actual ) {

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/session/GraphSession.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/session/GraphSession.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/session/GraphSession.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -65,9 +65,8 @@
 import org.jboss.dna.graph.request.MoveBranchRequest;
 import org.jboss.dna.graph.request.Request;
 import org.jboss.dna.graph.session.GraphSession.Authorizer.Action;
-import com.google.common.collect.ListMultimap;
 import com.google.common.collect.LinkedListMultimap;
-import com.google.common.collect.Multimaps;
+import com.google.common.collect.ListMultimap;
 
 /**
  * This class represents an interactive session for working with the content within a graph. This session maintains a cache of



More information about the dna-commits mailing list
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadNextBlockOfChildrenRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadNextBlockOfChildrenRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -203,13 +203,13 @@
      * 
      * @param actual the actual location of the node being read, or null if the {@link #startingAfter() starting after location}
      *        should be used
      * @throws IllegalArgumentException if the actual location does not represent the {@link Location#isSame(Location) same
      *         location} as the {@link #startingAfter() starting after location}, or if the actual location does not have a path.
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocationOfStartingAfterNode( Location actual ) {
         checkNotFrozen();
-        if (!startingAfter.isSame(actual)) { // not same if actual is null
+        if (!startingAfter.equals(actual)) { // not same if actual is null
             throw new IllegalArgumentException(GraphI18n.actualLocationNotEqualToInputLocation.text(actual, startingAfter));
         }
         assert actual != null;
@@ -203,13 +203,13 @@
      * @param actual the actual location of the node being read, or null if the {@link #startingAfter() starting after location}
      *        should be used
-     * @throws IllegalArgumentException if the actual location does not represent the {@link Location#isSame(Location) same
-     *         location} as the {@link #startingAfter() starting after location}, or if the actual location does not have a path.
+     * @throws IllegalArgumentException if the actual location is not {@link Location#equals(Object) equal to} the
+     *         {@link #startingAfter() starting after location}, or if the actual location does not have a path.
      * @throws IllegalStateException if the request is frozen
      */

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/ReadNodeRequest.java
===================================================================
--- trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/RenameNodeRequest.java	2009-11-30 20:08:48 UTC (rev 1371)
+++ trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/RenameNodeRequest.java	2009-11-30 21:53:47 UTC (rev 1372)
@@ -106,17 +106,16 @@
      * 
      * @param oldLocation the actual location of the node before being renamed
      * @param newLocation the actual location of the node after being renamed
      * @throws IllegalArgumentException if the either location is null or is missing its path, if the old location does not
      *         represent the {@link Location#isSame(Location) same location} as the {@link #at() current location}, if the new
      *         location does not have the same parent as the old location, or if the new location does not have the same
      *         {@link Path.Segment#getName() name} on {@link Path#getLastSegment() last segment} as that {@link #toName()
      *         specified on the request}
      * @throws IllegalStateException if the request is frozen
      */
     public void setActualLocations( Location oldLocation,
                                     Location newLocation ) {
         checkNotFrozen();
-        if (!at.isSame(oldLocation)) { // not same if actual is null
+        if (!at.equals(oldLocation)) { // not same if actual is null
             throw new IllegalArgumentException(GraphI18n.actualLocationNotEqualToInputLocation.text(oldLocation, at));
         }
         assert oldLocation != null;
@@ -106,17 +106,16 @@
      * @param oldLocation the actual location of the node before being renamed
      * @param newLocation the actual location of the node after being renamed
-     * @throws IllegalArgumentException if the either location is null or is missing its path, if the old location does not
-     *         represent the {@link Location#isSame(Location) same location} as the {@link #at() current location}, if the new
-     *         location does not have the same parent as the old location, or if the new location does not have the same
-     *         {@link Path.Segment#getName() name} on {@link Path#getLastSegment() last segment} as that {@link #toName()
-     *         specified on the request}
+     * @throws IllegalArgumentException if the either location is null or is missing its path, if the old location is not
+     *         {@link Location#equals(Object) equal to} the {@link #at() current location}, if the new location does not have the
+     *         same parent as the old location, or if the new location does not have the same {@link Path.Segment#getName() name}
+     *         on {@link Path#getLastSegment() last segment} as that {@link #toName() specified on the request}
      * @throws IllegalStateException if the request is frozen
      */

Modified: trunk/dna-graph/src/main/java/org/jboss/dna/graph/request/SetPropertyRequest.java
===================================================================